@@ -1,32 +1,33 @@
-/* 
-xdgkit
-Rusified in 2021 Copyright Israel Dahl. All rights reserved.
+// xdgkit
+// Rusified in 2021 Copyright Israel Dahl. All rights reserved.
+// 
+//        /VVVV\
+//      /V      V\
+//    /V          V\
+//   /      0 0     \
+//   \|\|\</\/\>/|/|/
+//        \_/\_/
+// 
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License version 2 as
+// published by the Free Software Foundation.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-	   /VVVV\
-	 /V	  V\
-   /V		  V\
-  /	  0 0	 \
-  \|\|\</\/\>/|/|/
-	   \_/\_/
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License version 2 as
-published by the Free Software Foundation.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-*/
 mod desktop_entry;
 mod basedir;
 mod icon_theme;
+mod desktop_menu;
 mod utils;
+mod categories;
+
 extern crate clap;
 use clap::{App, load_yaml};
 
@@ -83,7 +84,7 @@ fn main() {
 		let desktop_file = desktop_entry::DesktopEntry::new(filename.to_string());
 		//NOT OPTIONAL
 		if matches.is_present("Type") {
-			println!("{:?}",desktop_entry::string_xdg_type(desktop_file.xdg_type).unwrap_or("".to_string()));
+			println!("{:?}",desktop_file.xdg_type.to_string());
 		}
 		//NOT OPTIONAL
 		if matches.is_present("Version") {
